golds

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 8, 2019 License: BSD-3-Clause Imports: 0 Imported by: 0

README

golds = go (lang) data structures

Build Status License Go Report Card Codebeat codecov

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Comparable

type Comparable interface {
	Less(Comparable) bool
}

Comparable is an interface for comparable items contains only one method Less, which return true if an element is less than given

type Container

type Container interface {
	// Size returns amount of elements inside a collection
	Size() int

	// IsEmpty returns true if collection is empty
	IsEmpty() bool

	// Clear removes all elements from the collection
	Clear()
}

Container basic interface for all collections

Directories

Path Synopsis

Jump to